@@ -18,9 +18,14 @@ class MathMathML extends MathRenderer {
 	protected $allowedRootElements = '';
 	protected $hosts;
 
-	/** @var boolean if false MathML output is not validated */
+	/** @var bool if false MathML output is not validated */
 	private $XMLValidation = true;
+
+	/**
+	 * @var string|bool
+	 */
 	private $svgPath = false;
+
 	private $mathoidStyle;
 
 	public function __construct( $tex = '', $params = [] ) {
@@ -34,7 +39,7 @@ class MathMathML extends MathRenderer {
 				$this->setMathml( '<math>' . $tex . '</math>' );
 			} elseif ( $params['type'] == 'ascii' ) {
 				$this->inputType = 'ascii';
-			} elseif ( $params['type'] == 'chem' ){
+			} elseif ( $params['type'] == 'chem' ) {
 				$this->inputType = 'chem';
 			}
 		}
@@ -60,7 +65,7 @@ class MathMathML extends MathRenderer {
 	/**
 	 * Sets the XML validation.
 	 * If set to false the output of MathML is not validated.
-	 * @param boolean $validation
+	 * @param bool $validation
 	 */
 	public function setXMLValidation( $validation = true ) {
 		$this->XMLValidation = $validation;
@@ -75,9 +80,11 @@ class MathMathML extends MathRenderer {
 		$this->allowedRootElements = $settings;
 	}
 
-	/* (non-PHPdoc)
+	/**
 	 * @see MathRenderer::render()
-	*/
+	 * @param bool $forceReRendering
+	 * @return bool
+	 */
 	public function render( $forceReRendering = false ) {
 		global $wgMathFullRestbaseURL;
 		try {
@@ -117,7 +124,7 @@ class MathMathML extends MathRenderer {
 
 	/**
 	 * Helper function to checks if the math tag must be rendered.
-	 * @return boolean
+	 * @return bool
 	 */
 	private function renderingRequired() {
 		$logger = LoggerFactory::getInstance( 'Math' );
@@ -156,10 +163,10 @@ class MathMathML extends MathRenderer {
 	 * @global int $wgMathLaTeXMLTimeout
 	 * @param string $host
 	 * @param string $post the encoded post request
-	 * @param mixed $res the result
-	 * @param mixed $error the formatted error message or null
+	 * @param mixed &$res the result
+	 * @param mixed &$error the formatted error message or null
 	 * @param String $httpRequestClass class name of MWHttpRequest (needed for testing only)
-	 * @return boolean success
+	 * @return bool success
 	 */
 	public function makeRequest(
 			$host, $post, &$res, &$error = '', $httpRequestClass = 'MWHttpRequest'
@@ -176,9 +183,8 @@ class MathMathML extends MathRenderer {
 			$this->getPostData();
 		}
 		$options = [ 'method' => 'POST', 'postData' => $post, 'timeout' => $wgMathLaTeXMLTimeout ];
-		/** @var $req (CurlHttpRequest|PhpHttpRequest) the request object  */
+		/** @var CurlHttpRequest|PhpHttpRequest $req the request object */
 		$req = $httpRequestClass::factory( $host, $options );
-		/** @var Status $req Status the request status */
 		$status = $req->execute();
 		if ( $status->isGood() ) {
 			$res = $req->getContent();
@@ -197,7 +203,7 @@ class MathMathML extends MathRenderer {
 				$errormsg = $status->getHtml();
 				$error =
 					$this->getError( 'math_invalidresponse', $this->getModeStr(), $host, $errormsg,
-						$this->getModeStr( 'mathml' ) );
+						$this->getModeStr() );
 				LoggerFactory::getInstance( 'Math' )->warning( 'NoResponse:' . var_export( [
 						'post' => $post,
 						'host' => $host,
@@ -248,7 +254,7 @@ class MathMathML extends MathRenderer {
 
 	/**
 	 * Does the actual web request to convert TeX to MathML.
-	 * @return boolean
+	 * @return bool
 	 */
 	protected function doRender() {
 		if ( $this->getTex() === '' ) {
@@ -303,7 +309,7 @@ class MathMathML extends MathRenderer {
 	 * Checks if the input is valid MathML,
 	 * and if the root element has the name math
 	 * @param string $XML
-	 * @return boolean
+	 * @return bool
 	 */
 	public function isValidMathML( $XML ) {
 		$out = false;
@@ -333,8 +339,8 @@ class MathMathML extends MathRenderer {
 	}
 
 	/**
-	 * @param boolean $noRender
-	 * @return type
+	 * @param bool $noRender
+	 * @return Title|string
 	 */
 	private function getFallbackImageUrl( $noRender = false ) {
 		if ( $this->svgPath ) {
@@ -351,7 +357,7 @@ class MathMathML extends MathRenderer {
 	/**
 	 * Helper function to correct the style information for a
 	 * linked SVG image.
-	 * @param string $style current style information to be updated
+	 * @param string &$style current style information to be updated
 	 */
 	public function correctSvgStyle( &$style ) {
 		if ( preg_match( '/style="([^"]*)"/', $this->getSvg(), $styles ) ) {
@@ -379,9 +385,9 @@ class MathMathML extends MathRenderer {
 
 	/**
 	 * Gets img tag for math image
-	 * @param boolean $noRender if true no rendering will be performed
+	 * @param bool $noRender if true no rendering will be performed
 	 * if the image is not stored in the database
-	 * @param boolean|string $classOverride if classOverride
+	 * @param bool|string $classOverride if classOverride
 	 * is false the class name will be calculated by getClassName
 	 * @return string XML the image html tag
 	 */
@@ -414,7 +420,7 @@ class MathMathML extends MathRenderer {
 
 	/**
 	 * Calculates the default class name for a math element
-	 * @param boolean $fallback
+	 * @param bool $fallback
 	 * @return string the class name
 	 */
 	private function getClassName( $fallback = false ) {
@@ -493,7 +499,6 @@ class MathMathML extends MathRenderer {
 			$this->userInputTex = $rpage->math_input;
 		}
 		parent::initializeFromDatabaseRow( $rpage );
-
 	}
 
 	/**
