@@ -9,7 +9,6 @@
  * @file
  */
 
-
 /**
  * Takes LaTeX fragments and outputs the source directly to the browser
  *
@@ -23,7 +22,7 @@ class MathSource extends MathRenderer {
 	 * @param string $tex
 	 * @param array $params
 	 */
-	function __construct( $tex = '', $params = array() ) {
+	function __construct( $tex = '', $params = [] ) {
 		parent::__construct( $tex, $params );
 		$this->setMode( 'source' );
 	}
@@ -44,24 +43,24 @@ class MathSource extends MathRenderer {
 		return Xml::element( 'span',
 			$this->getAttributes(
 				'span',
-				array(
+				[
 					// the former class name was 'tex'
 					// for backwards compatibility we keep this classname
 					'class' => $class. ' tex',
 					'dir' => 'ltr'
-				)
+				]
 			),
 			'$ ' . str_replace( "\n", " ", $this->getTex() ) . ' $'
 		);
 	}
 
 	protected function getMathTableName() {
-		throw new Exception ( 'in math source mode no database caching should happen');
+		throw new Exception( 'in math source mode no database caching should happen' );
 	}
 
 	/**
 	 * No rendering required in plain text mode
-	 * @return boolean
+	 * @return bool
 	 */
 	function render() {
 		// assume unchanged to avoid unnecessary database access
