@@ -1,7 +1,13 @@
 <?php
+
 /**
  * Test the Id feature
+ *
+ * @covers MathRenderer
+ *
  * @group Math
+ *
+ * @licence GNU GPL v2+
  */
 class MathIdTest extends MediaWikiTestCase {
 
@@ -10,8 +16,8 @@ class MathIdTest extends MediaWikiTestCase {
 	 */
 	public function testBasics() {
 		define( 'RANDOM_ID', 'a_random_id' );
-		$renderer = MathRenderer::getRenderer( "a+b", array( 'id' => RANDOM_ID ) );
-		$this->assertEquals( RANDOM_ID, $renderer->getId() );
+		$renderer = MathRenderer::getRenderer( "a+b", [ 'id' => RANDOM_ID ] );
+		$this->assertEquals( RANDOM_ID, $renderer->getID() );
 	}
 
 }
