@@ -1,9 +1,13 @@
 <?php
+
 /**
+ * @covers MathInputCheck
+ *
  * @group Math
+ *
+ * @licence GNU GPL v2+
  */
-class MathInputCheckTest extends MediaWikiTestCase
-{
+class MathInputCheckTest extends MediaWikiTestCase {
 	/**
 	 * @covers MathInputCheck::isValid
 	 */
@@ -26,7 +30,7 @@ class MathInputCheckTest extends MediaWikiTestCase
 	 */
 	public function testGetValidTex() {
 		$InputCheck = $this->getMockBuilder( 'MathInputCheck' )
-			->setConstructorArgs( array( 'some tex input' ) )
+			->setConstructorArgs( [ 'some tex input' ] )
 			->getMock();
 		$this->assertNull( $InputCheck->getValidTex() );
 	}
