@@ -1,9 +1,14 @@
 <?php
+
 /**
-* Test the LaTeXML output format.
-*
-* @group Math
-*/
+ * Test the LaTeXML output format.
+ *
+ * @covers MathLaTeXML
+ *
+ * @group Math
+ *
+ * @licence GNU GPL v2+
+ */
 class MathLaTeXMLTest extends MediaWikiTestCase {
 
 	/**
@@ -12,15 +17,16 @@ class MathLaTeXMLTest extends MediaWikiTestCase {
 	 */
 	public function testSerializeSettings() {
 		$renderer = $this->getMockBuilder( 'MathLaTeXML' )
-			->setMethods( NULL )
+			->setMethods( null )
 			->disableOriginalConstructor()
 			->getMock();
-		$sampleSettings = array(
+		$sampleSettings = [
 			'k1' => 'v1',
 			'k2&=' => 'v2 + & *üö',
-			'k3' => array(
+			'k3' => [
 				'v3A', 'v3b'
-			) );
+			]
+		];
 		$expected = 'k1=v1&k2%26%3D=v2+%2B+%26+%2A%C3%BC%C3%B6&k3=v3A&k3=v3b';
 		$this->assertEquals(
 			$expected,
